@@ -63,7 +63,7 @@ def set_vml_num_threads(nthreads):
     Suggests a maximum number of threads to be used in VML operations.
 
     This function is equivalent to the call
-    `mkl_domain_set_num_threads(nthreads, MKL_VML)` in the MKL
+    `mkl_domain_set_num_threads(nthreads, MKL_DOMAIN_VML)` in the MKL
     library.  See:
 
     http://www.intel.com/software/products/mkl/docs/webhelp/support/functn_mkl_domain_set_num_threads.html
@@ -105,14 +105,14 @@ def detect_number_of_cores():
             ncpus = os.sysconf("SC_NPROCESSORS_ONLN")
             if isinstance(ncpus, int) and ncpus > 0:
                 return ncpus
-        else: # OSX:
+        else:  # OSX:
             return int(subprocess.check_output(["sysctl", "-n", "hw.ncpu"]))
     # Windows:
     if os.environ.has_key("NUMBER_OF_PROCESSORS"):
         ncpus = int(os.environ["NUMBER_OF_PROCESSORS"]);
         if ncpus > 0:
             return ncpus
-    return 1 # Default
+    return 1  # Default
 
 
 class CacheDict(dict):
